fenics\_plotly package
======================

Submodules
----------

fenics\_plotly.fenics\_plotly module
------------------------------------

.. automodule:: fenics_plotly.fenics_plotly
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: fenics_plotly
   :members:
   :undoc-members:
   :show-inheritance:
